<?
# session
$SES_MEMBER_ID              = $this->session->userdata('C_Member_Id');
$SES_MEMBER_NICNAME         = $this->session->userdata('C_Member_Nicname');

$controller = $this->uri->segment(2);

$this->load->helper('cookie');
$comment_sns_id 		= get_cookie('crossmap_comment_sns_id');
$comment_sns_name 		= get_cookie('crossmap_comment_sns_name');
$comment_sns_type 		= get_cookie('crossmap_comment_sns_type');

?>


<div id="user_comment_layer" style="display:none;">
	<div class="popup_wrap2_d" style=" z-index: 9998;">
		<div class="popupbox2_d" style=" width:810px;">
			<div class="popuptop3_d">
				<h3 class="p_title2"><strong><span id="user_comment_nicname"><?=$SES_MEMBER_NICNAME?></span></strong> 님의 댓글
					<span style="padding-left:40px;"><a href="javascript:change_user_comment_content_type(3)" class="current" id="user_comment_menu3">라이프</a> | <a href="javascript:change_user_comment_content_type(1)" id="user_comment_menu1">뉴스</a> | <a href="javascript:change_user_comment_content_type(2)" id="user_comment_menu2">칼럼</a></span>
				</h3>
				<a href="javascript:change_toggle('my_comment_policy')"><span class="btn-tit">댓글운영정책</span></a>
				<span class="btn-info"><a href="javascript:change_toggle('my_comment_policy')"><img src="/img/web/btn-info.png"></a></span>
				<span class="btn-close"><a href="javascript:commonLayerClose('user_comment_layer')"><img src="/img/web/btn-close2.png"></a></span>

				<div class="delivery_info3" id="my_comment_policy" style="display:none;">
					<p class="d_info_tit" style="text-align:center; margin:10px 0">댓글운영정책</p>
					<p class="d_info_txt">크로스맵 댓글은 게시물에 대하여 자신의 생각을 말하고 남의 생각을 들으며 서로 다양한 의견을 나누는 공간입니다. 그러나 간혹 불건전한 내용을 올리시는 분들이 계셔서 건전한 인터넷문화 정착을 위해 아래와 같은 운영원칙을 적용합니다.<br><br><span style="text-decoration:underline; margin-bottom: 15px;display: inline-block;">1. 댓글의 삭제 및 제한 조치</span><br>네티즌들의 신고 또는 자제 모니터링을 통해 아래에 해당하는 내용이 포함된 댓글이 발견되면 예고없이 삭제 또는 제한 조치를 하겠습니다. <br></p>
					<table style="font-size:13px;">
					<tr>
						<td>1) 타인에 대한 욕설 또는 비방 </td>
						<td>2) 인신공격 또는 명예훼손 </td>
					</tr>
					<tr>
						<td>3) 개인정보 유출 또는 사생활 침해</td>
						<td>4) 음란성 내용 또는 음란물 링크 </td>
					</tr>
					<tr>
						<td>5) 상업적 광고 또는 사이트/홈피 홍보&nbsp;&nbsp;&nbsp;</td>
						<td>6) 불법정보 유출</td>
					</tr>
					<tr>
						delivery_info3	<td>7) 같은 내용의 반복(도배) </td>
						<td>8) 폭력 또는 사행심 조장 </td>
					</tr>
					<tr>
						<td>9) 기타 게시물 내용과 관계없는 내용</td>
						<td></td>
					</tr>
					</table>
					<br><br>
					<p class="d_info_txt"><span style="text-decoration:underline; margin-bottom: 15px;display: inline-block;">2. 댓글 작성에 대한 제한</span><br>불건전한 댓글은 발견시 별도의 통보없이 즉시 삭제 또는 제한 조치 하며 상습적 또는 위반 정도가 심한 댓글을 올리시는 분에 대해서는 일정 기간 댓글 작성에 대한 권한을 제한할 수 있습니다.<br>또한 비정상적인 패턴으로 조회, 추천, 반대 등이 발생하는 것으로 관리자 또는 시스템이 판단하는 경우 부정 클릭여부를 확인하여 해당 IP나 ID를 제재할 수 있습니다.<br>명예훼손, 개인정보유츨, 욕설 등 법률에 위반되는 댓글은 관계 법령에 의거 민형사상 처벌을 받을 수 있으니 이용에 주의를 부탁 드립니다.<br><br><span style="text-decoration:underline; margin-bottom: 15px;display: inline-block;">3. 뉴스, 칼럼 댓글함 전체공개</span><br>건전한 댓글 문화를 위하여 뉴스 및 칼럼 댓글에 한해서만 댓글모음이 전체공개됩니다. 제공되는 목록에 삭제한 댓글이나 답글은 포함되지 않습니다. <br></p>
					<div class="form-group" style="margin:20px 0; display:block; text-align:center">
						<button type="button" class="btn btn-success" style="padding:5px 20px; font-size:14px" onclick="change_toggle('my_comment_policy')"">확인</button>
					</div>
				</div>
			</div>
			<div class="popupbody3_d" >
				<div class="pop_tit">
					댓글/답글 <span class="beachblue" id="user_comment_count"></span>
					<div class="reply_sort_d">
						<span><a href="javascript:change_user_comment_sort(1)" id="user_comment_sort1">호감순</a></span>
						<span><a href="javascript:change_user_comment_sort(2)" id="user_comment_sort2" class="current">최신순</a></span>
						<span><a href="javascript:change_user_comment_sort(3)" id="user_comment_sort3">과거순</a></span>
						<span><a href="javascript:change_user_comment_sort(4)" id="user_comment_sort4">답글순</a></span>
					</div>
				</div>

				<div id="user_comment_list"></div>
				<div style="height:30px;display:none" id="user_comment_bottom"></div>
				<div class="btn btn-default btn_life" id="user_comment_more_btn">
					<a href="javascript:user_comment_list();">더보기 </a><img src="/img/web/img_replyopen.gif">
				</div>
			</div>
		</div>
	</div>
	<div class="mask" style="z-index: 9997"></div>
</div>




<? require_once(APPPATH . "views/web/comm/comment_spam_layer_inc.php");?>


<script>


var user_comment_page = 1;
var user_comment_content_type = '3';
var user_comment_write_id = '<?=$comment_sns_id?>';
var user_comment_sort = '2';



$(".mask").on('click', function(event){
    $(event.target).parent().hide();

});

$('.user_replay_text').click(function(e) {
	$("#social_login").toggle();

    $(".popup_wrap").css('left','50%');
	$(".popup_wrap").css('top',popH+'px');

});

$('.user_comment_text').on('keyup', function(event) {
	var key = $(this).attr('strA');
	var len = $(this).val().length;
   	if (len >= 300) {
      	$(this).val($(this).val().substring(0, 300));
		len = 300;
   	}
   	$("#user_reply_text_count"+key).html(len+'/300');
});





// sort
function change_user_comment_sort(type){
	user_comment_sort = type;
	user_comment_page = 1;
	user_comment_list();

	$('#user_comment_sort1').toggleClass('current');
    $('#user_comment_sort2').toggleClass('current');
    $('#user_comment_sort3').toggleClass('current');
    $('#user_comment_sort4').toggleClass('current');
}


// content_type
function change_user_comment_content_type(type){
	user_comment_content_type = type;
	user_comment_page = 1;
	user_comment_list();

	$('#user_comment_menu1').removeClass('current');
    $('#user_comment_menu2').removeClass('current');
    $('#user_comment_menu3').removeClass('current');

    $('#user_comment_menu'+type).addClass('current');



}


function user_comment_list() {

	var form_data = {
		"page"          : user_comment_page,
		"content_type"  : user_comment_content_type,
		"write_id"  	: user_comment_write_id,
		"sort"  		: user_comment_sort
	};
	$.ajax({
        url: '/web/comm/user_comment_list',
        async: false,
        type: 'POST',
        dataType: 'HTML',
        data: form_data,
        success: function (rtnHtml) {
        	if(rtnHtml=='') return false;
			var arrHtml = rtnHtml.split("|||||");
			if(arrHtml[0].trim()=='0000') {
			    if(user_comment_page == 1) {
			        $("#user_comment_list").html(arrHtml[1]);
                } else {
                    $("#user_comment_list").append(arrHtml[1]);
                }
                var total_count = setComma(arrHtml[2]);
                $("#user_comment_count").html(total_count);

				if (arrHtml[3] == "N") {
					$("#user_comment_more_btn").hide();
					$("#user_comment_bottom").show();
				} else {
					$("#user_comment_more_btn").show();
					$("#user_comment_bottom").hide();
				}
				user_comment_page++;

			} else {
				alert(arrHtml[1]);
               	return false;
			}
        },
        error: function (rtnHtml) {
            alert('데이터 가져오기에 실패했습니다.');
            return false;
        }
    });
}

// 대댓글 더보기
function user_comment_reply_more(idx){
	var page = $("#user_comment_reply_page"+idx).val();
	page = parseInt(page) + 1;
	$("#user_comment_reply_page"+idx).val(page);
	user_comment_reply_list(idx, page);

}


var user_comment_reply_open_type = 1;
function user_comment_reply_open(idx){

	if(user_comment_reply_open_type ==1) {
        $("#user_comment_reply_box"+idx).css("display","block");
		user_comment_reply_list(idx, 1);

        user_comment_reply_open_type = 2;
    } else {
        $("#user_comment_reply_box"+idx).css("display","none");
        user_comment_reply_open_type = 1;
    }


}


function user_comment_reply_list(idx, page) {
	var form_data = {
		"page"      	: page,
		"sort"      	: user_comment_sort,
		"comment_idx"	: idx,
		"type"			: "user_comment"
	};
	$.ajax({
        url: '/web/comm/comment_reply_list',
        async: false,
        type: 'POST',
        dataType: 'HTML',
        data: form_data,
        success: function (rtnHtml) {
        	if(rtnHtml=='') return false;
			var arrHtml = rtnHtml.split("|||||");
			if(arrHtml[0].trim()=='0000') {
			    if(page == 1) {
			        $("#user_comment_reply_list"+idx).html(arrHtml[1]);
                } else {
                    $("#user_comment_reply_list"+idx).append(arrHtml[1]);
                }
                var total_count = setComma(arrHtml[2]);
                $("#user_comment_reply_count").html(total_count);
				console.log(arrHtml[3]);
				if (arrHtml[3] == "N") {
					$("#user_comment_reply_more_btn"+idx).hide();
				} else {
					$("#user_comment_reply_more_btn"+idx).show();
				}
			} else {
				alert(arrHtml[1]);
               	return false;
			}
        },
        error: function (rtnHtml) {
            alert('데이터 가져오기에 실패했습니다.');
            return false;
        }
    });
	$("#user_comment_reply_box"+idx).show();



}




// 대대글 달기
function user_comment_reply_add_proc(p_idx, content_idx){
	if("<?=$comment_sns_id?>"=="") {
		alert("로그인 후에 이용가능합니다.");
		return;
	}

	if($("#user_comment"+p_idx).val()=="") {
		alert("댓글을 입력해주세요.");
		return;
	}

	var form_data = {
		"p_idx"					: p_idx,
		"content_idx"			: content_idx,
		"content_type"			: user_comment_content_type,
		"comment"				: $("#user_comment"+p_idx).val()
	};
	$.ajax({
        url: '/web/comm/comment_add_proc',
        async: false,
        type: 'POST',
        dataType: 'JSON',
        data: form_data,
		success: function (rtnJson) {
        	if (rtnJson.code == "0000") {
				$("#user_comment"+p_idx).val('');
				$("#user_reply_text_count"+p_idx).html('0/300');
				$("#user_comment_reply_page"+p_idx).val(1);

				user_comment_reply_list(p_idx, 1);

            } else {
                alert(rtnJson.msg);
                return false;
            }

        },
        error: function (rtnJson) {
            alert('저장에 실패했습니다.');
            return false;
        }


    });

}


function user_comment_del(idx){
	if(confirm("댓글이 삭제됩니다. 삭제하시겠습니까?") == false) {
		return false;
	}


    var form_data = {
        "idx"			: idx
    };
    $.ajax({
        url: '/web/comm/user_comment_del_proc',
        async: false,
        type: 'POST',
        dataType: 'JSON',
        data: form_data,
        success: function (rtnJson) {
            if (rtnJson.code == "0000") {
            	user_comment_page = 1;
                user_comment_list();

            } else {
                alert(rtnJson.msg);
                return false;
            }
        },
        error: function (rtnJson) {
            alert('삭제에 실패했습니다.');
            return false;
        }
    });

}


function user_reply_comment_del(idx, p_idx){
	if(confirm("댓글이 삭제됩니다. 삭제하시겠습니까?") == false) {
		return false;
	}


    var form_data = {
        "idx"			: idx
    };
    $.ajax({
        url: '/web/comm/user_comment_del_proc',
        async: false,
        type: 'POST',
        dataType: 'JSON',
        data: form_data,
        success: function (rtnJson) {
            if (rtnJson.code == "0000") {
            	user_comment_reply_list(p_idx, 1);
            } else {
                alert(rtnJson.msg);
                return false;
            }
        },
        error: function (rtnJson) {
            alert('삭제에 실패했습니다.');
            return false;
        }
    });

}



function user_comment(write_id, write_name){
	user_comment_page = 1;
	user_comment_write_id = write_id;
	user_comment_list();
	$("#user_comment_layer").show();
	$("html, body").scrollTop(0);
	if(write_name!='') {
		$("#user_comment_nicname").html(write_name);
	}
}




function copy_user_comment_url(idx){
    $('#copy_user_comment_url'+idx).select();
    try {
        document.execCommand('copy');
        alert("주소가 복사되었습니다.")
    } catch (err) {
        alert('이 브라우저는 지원하지 않습니다.')
    }
}



// 댓글 좋아요
function user_comment_like_select(type, idx){
	if("<?=$SES_MEMBER_ID?>"=="") {
        alert("로그인 후에 이용가능합니다.");
        return;
    }
	var form_data = {
		"comment_idx"			: idx,
		"type"					: type
	};
	$.ajax({
        url: '/web/comm/comment_like_proc',
        async: false,
        type: 'POST',
        dataType: 'JSON',
        data: form_data,
        success: function (rtnJson) {
            if (rtnJson.code == "0000") {
            	var like_count 	= setComma(rtnJson.data.like_count);
            	var bad_count 	= setComma(rtnJson.data.bad_count);
				$("#comment_like1_"+idx).html(like_count);
				$("#comment_like2_"+idx).html(bad_count);

            } else {
                alert("저장에 실패했습니다.");
                return false;
            }
        },
        error: function (rtnJson) {
            alert('저장에 실패했습니다.');
            return false;
        }
    });

}




function logout_advice(){
	alert("로그아웃 후에 이용해주세요.");
	return false;
}






</script>
